=======
Credits
=======

Development Lead
----------------

* Leszek Walerys

Author of the original `satel_integra`
--------------------------------------
* Krzysztof Machelski <krzysztof.machelski+pypi@gmail.com>

Contributors
------------

* Grzegorz Wisniewski <grzeg.wisniewski@gmail.com>
* Grzegorz Szostak <szostak.grzegorz@gmail.com>
* Michał Jonik <michal.jonik@gmail.com>
